Struct amazon_sp_finances::models::list_financial_event_groups_payload::ListFinancialEventGroupsPayload
source · [−]pub struct ListFinancialEventGroupsPayload {
pub next_token: Option<String>,
pub financial_event_group_list: Option<Vec<FinancialEventGroup>>,
}Expand description
ListFinancialEventGroupsPayload : The payload for the listFinancialEventGroups operation.
Fields
next_token: Option<String>When present and not empty, pass this string token in the next request to return the next response page.
financial_event_group_list: Option<Vec<FinancialEventGroup>>A list of financial event group information.
Implementations
sourceimpl ListFinancialEventGroupsPayload
impl ListFinancialEventGroupsPayload
sourcepub fn new() -> ListFinancialEventGroupsPayload
pub fn new() -> ListFinancialEventGroupsPayload
The payload for the listFinancialEventGroups operation.